package zero1hd.rhythmbullet.graphics.ui.components;

import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.scenes.scene2d.ui.Image;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.WidgetGroup;
import com.badlogic.gdx.scenes.scene2d.utils.TextureRegionDrawable;
import com.badlogic.gdx.utils.Disposable;

import zero1hd.rhythmbullet.audio.SongInfo;

public class MusicSelectable extends WidgetGroup implements Disposable {
	private Table table;

	private Image imageIcon;
	private ScrollText displayName;
	private Label durationLabel;
	private Label authorLabel;

	private FileHandle musicFile;

	private Texture albumCover;
	private SongInfo songInfo;
	
	private boolean selected;
	
	public MusicSelectable(FileHandle musicFile, Preferences musicAnnotation, Skin skin, Texture defaultAlbumC) {
		table = new Table(skin);
		table.setBackground("holo-pane");

		setName(musicFile.name());
		table.defaults().pad(10f);

		this.albumCover = defaultAlbumC;
		this.musicFile = musicFile;
		songInfo = new SongInfo(musicFile, musicAnnotation);

		imageIcon = new Image(albumCover);
		table.add(imageIcon).size(115).padTop(15).center();

		displayName = new ScrollText(musicFile.nameWithoutExtension().replace('_', ' '), null, skin, true, false);
		table.add(displayName).expandX().fillX();

		table.row();

		durationLabel = new Label("Loading...", skin, "sub-font", skin.getColor("default"));
		table.add(durationLabel);

		authorLabel = new Label("Loading...", skin, "sub-font", skin.getColor("default"));
		table.add(authorLabel);

		
		addActor(table);
	}
	
	/**
	 * updates the UI side of information.
	 * needs to be called in thread with gl context.
	 */
	public void updateInfo() {
		durationLabel.setText("Runtime: "
				+ ((songInfo.getDurationInSeconds() / 60 < 1) ? "00" : songInfo.getDurationInSeconds() / 60) + ":"
				+ ((songInfo.getDurationInSeconds() - (songInfo.getDurationInSeconds() / 60) * 60) < 10
						? "0" + (songInfo.getDurationInSeconds() - (songInfo.getDurationInSeconds() / 60) * 60)
						: (songInfo.getDurationInSeconds() - (songInfo.getDurationInSeconds() / 60) * 60)));
		authorLabel.setText("Author: " + songInfo.getAuthor());
		
		songInfo.setupTexture(albumCover);
		albumCover = songInfo.getAlbumCover();
		imageIcon.setDrawable((new TextureRegionDrawable(new TextureRegion(albumCover))));
	}
	
	@Override
	public void act(float delta) {
		table.setSize(getWidth(), getHeight());
		super.act(delta);
	}
	
	public FileHandle getMusicFile() {
		return musicFile;
	}

	public SongInfo getAudioInfo() {
		return songInfo;
	}

	@Override
	public void dispose() {
		songInfo.dispose();
	}

	public boolean isMusicInvalid() {
		return songInfo.isInvalidMusic();
	}
	
	public void select() {
		table.setBackground("holo-pane-down");
		selected = true;
	}
	
	public void diselect() {
		table.setBackground("holo-pane");
		selected = false;
	}
	
	public boolean isSelected() {
		return selected;
	}
}
